'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getHandlerForAction = exports.getActionType = undefined;

var _constants = require('./constants');

var _keyHandlers = require('./keyHandlers');

var _keyHandlers2 = _interopRequireDefault(_keyHandlers);

var _key = require('./key');

var _key2 = _interopRequireDefault(_key);

var _isEqual = require('lodash/isEqual');

var _isEqual2 = _interopRequireDefault(_isEqual);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/**
 * Create an array of action types with key names that map to these types and
 * whether the modifier key should be pressed.
 */
var createActionTypes = function createActionTypes(options) {
  return [{
    type: _constants.ACTION_TYPES.NUMBER,
    names: ['0', '1', '2', '3', '4', '5', '6', '7', '8', '9'],
    modifierKeys: []
  }, {
    type: _constants.ACTION_TYPES.MINUS,
    names: ['-'],
    modifierKeys: []
  }, {
    type: _constants.ACTION_TYPES.DECIMAL,
    names: [options.decimal, 'decimal'],
    modifierKeys: []
  }, {
    type: _constants.ACTION_TYPES.THOUSANDS,
    names: [options.thousands, 'separator'],
    modifierKeys: []
  }, {
    type: _constants.ACTION_TYPES.SHORTCUT,
    names: Object.keys(options.shortcuts),
    modifierKeys: []
  }, {
    type: _constants.ACTION_TYPES.BACKSPACE,
    names: ['backspace'],
    modifierKeys: []
  }, {
    type: _constants.ACTION_TYPES.DELETE,
    names: ['delete', // Chrome & Firefox
    'del' // Edge & IE
    ],
    modifierKeys: []
  }, {
    type: _constants.ACTION_TYPES.UNDO,
    names: ['z'],
    modifierKeys: [_key2.default.getHistoryKey()]
  }, {
    type: _constants.ACTION_TYPES.REDO,
    names: ['y'],
    modifierKeys: [_key2.default.getHistoryKey()]
  }];
};

/**
 * Determines what type of action needs to be dealt with from the current
 * key information. E.g. vertical arrow pressed, number pressed etc...
 * @param {keyInfo} Information about the pressed key
 */
var getActionType = exports.getActionType = function getActionType(keyInfo, options) {
  var _iteratorNormalCompletion = true;
  var _didIteratorError = false;
  var _iteratorError = undefined;

  try {
    for (var _iterator = createActionTypes(options)[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
      var actionType = _step.value;

      var typeMatch = actionType.names.indexOf(keyInfo.keyName) > -1;
      var modifierMatch = (0, _isEqual2.default)(actionType.modifierKeys, keyInfo.modifierKeys);

      if (typeMatch && modifierMatch) {
        return actionType.type;
      }
    }
  } catch (err) {
    _didIteratorError = true;
    _iteratorError = err;
  } finally {
    try {
      if (!_iteratorNormalCompletion && _iterator.return) {
        _iterator.return();
      }
    } finally {
      if (_didIteratorError) {
        throw _iteratorError;
      }
    }
  }

  return _constants.ACTION_TYPES.UNKNOWN;
};

var getHandlerForAction = exports.getHandlerForAction = function getHandlerForAction(action) {
  var _handlerForAction;

  var handlerForAction = (_handlerForAction = {}, _defineProperty(_handlerForAction, _constants.ACTION_TYPES.NUMBER, _keyHandlers2.default.onNumber), _defineProperty(_handlerForAction, _constants.ACTION_TYPES.DECIMAL, _keyHandlers2.default.onDecimal), _defineProperty(_handlerForAction, _constants.ACTION_TYPES.THOUSANDS, _keyHandlers2.default.onThousands), _defineProperty(_handlerForAction, _constants.ACTION_TYPES.MINUS, _keyHandlers2.default.onMinus), _defineProperty(_handlerForAction, _constants.ACTION_TYPES.SHORTCUT, _keyHandlers2.default.onShortcut), _defineProperty(_handlerForAction, _constants.ACTION_TYPES.BACKSPACE, _keyHandlers2.default.onBackspace), _defineProperty(_handlerForAction, _constants.ACTION_TYPES.DELETE, _keyHandlers2.default.onDelete), _defineProperty(_handlerForAction, _constants.ACTION_TYPES.UNDO, _keyHandlers2.default.onUndo), _defineProperty(_handlerForAction, _constants.ACTION_TYPES.REDO, _keyHandlers2.default.onRedo), _defineProperty(_handlerForAction, _constants.ACTION_TYPES.UNKNOWN, _keyHandlers2.default.onUnknown), _handlerForAction);

  return handlerForAction[action];
};